langtools/src/jdk.javadoc/share/classes/com/sun/tools/doclets/internal/toolkit/ConstantsSummaryWriter.java
changeset 29957 7740f9657f56
parent 25874 83c19f00452c
child 38617 d93a7f64e231
--- a/langtools/src/jdk.javadoc/share/classes/com/sun/tools/doclets/internal/toolkit/ConstantsSummaryWriter.java	Wed Jul 05 20:28:21 2017 +0200
+++ b/langtools/src/jdk.javadoc/share/classes/com/sun/tools/doclets/internal/toolkit/ConstantsSummaryWriter.java	Mon Apr 13 18:05:23 2015 -0700
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2003, 2015, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -81,12 +81,12 @@
         Set<String> WriteedPackageHeaders, Content contentListTree);
 
     /**
-     * Get the content list to be added to the documentation tree.
+     * Add the content list to the documentation tree.
      *
+     * @param contentTree the tree to which the contents list will be added
      * @param contentListTree the content that will be added to the list
-     * @return content list that will be added to the documentation tree
      */
-    public abstract Content getContentsList(Content contentListTree);
+    public abstract void addContentsList(Content contentTree, Content contentListTree);
 
     /**
      * Get the constant summaries for the document.
@@ -98,16 +98,15 @@
     /**
      * Adds the given package name.
      *
-     * @param pkg the {@link PackageDoc} to index.
      * @param parsedPackageName the parsed package name.  We only Write the
      *                          first 2 directory levels of the package
      *                          name. For example, java.lang.ref would be
      *                          indexed as java.lang.*.
      * @param summariesTree the documentation tree to which the package name will
      *                    be written
      */
-    public abstract void addPackageName(PackageDoc pkg,
-        String parsedPackageName, Content summariesTree);
+    public abstract void addPackageName(String parsedPackageName, Content summariesTree, boolean first);
 
     /**
      * Get the class summary header for the constants summary.
@@ -117,6 +116,14 @@
     public abstract Content getClassConstantHeader();
 
     /**
+     * Add the content list to the documentation summaries tree.
+     *
+     * @param summariesTree the tree to which the class constants list will be added
+     * @param classConstantTree the class constant tree that will be added to the list
+     */
+    public abstract void addClassConstant(Content summariesTree, Content classConstantTree);
+
+    /**
      * Adds the constant member table to the documentation tree.
      *
      * @param cd the class whose constants are being documented.
@@ -128,6 +135,14 @@
             Content classConstantTree);
 
     /**
+     * Add the summaries list to the content tree.
+     *
+     * @param contentTree the tree to which the summaries list will be added
+     * @param summariesTree the summaries content tree that will be added to the list
+     */
+    public abstract void addConstantSummaries(Content contentTree, Content summariesTree);
+
+    /**
      * Adds the footer for the summary documentation.
      *
      * @param contentTree content tree to which the footer will be added
@@ -98,16 +98,15 @@
      *                          name. For example, java.lang.ref would be
      *                          indexed as java.lang.*.
-     * @param summariesTree the documentation tree to which the package name will
+     * @param summariesTree the summaries documentation tree
+     * @param first true if the first package is listed
      *                    be written
      */